==> django_nativemojo-0.1.77.tar.gz: django_nativemojo-0.1.77/mojo/apps/incident/handlers/event_handlers.py <==
"""
Event handlers for incident processing.

This module contains handlers for processing incident events based on different
handler types (task, email, notify). These handlers are used by the RuleSet.run_handler
method to handle events that match rule criteria.
"""

class TaskHandler:
    """
    Handler for executing tasks based on events.
    
    This handler executes a named task with the given parameters
    when an event matches rule criteria.
    
    Attributes:
        handler_name (str): The name of the task to execute.
        params (dict): Parameters to pass to the task.
    """
    
    def __init__(self, handler_name, **params):
        """
        Initialize a TaskHandler with a task name and parameters.
        
        Args:
            handler_name (str): The name of the task to execute.
            **params: Parameters to pass to the task.
        """
        self.handler_name = handler_name
        self.params = params
        
    def run(self, event):
        """
        Execute the task for the given event.
        
        Args:
            event (Event): The event that triggered this handler.
            
        Returns:
            bool: True if the task was executed successfully, False otherwise.
        """
        # TODO: Implement actual task execution logic
        # For example, using Celery to execute tasks asynchronously
        try:
            # Example implementation:
            # from mojo.tasks import execute_task
            # result = execute_task.delay(self.handler_name, event=event, **self.params)
            # return result.successful()
            return True
        except Exception as e:
            # Log the error
            # logger.error(f"Error executing task {self.handler_name}: {e}")
            return False


class EmailHandler:
    """
    Handler for sending email notifications based on events.
    
    This handler sends an email to the specified recipient
    when an event matches rule criteria.
    
    Attributes:
        recipient (str): The email address to send notifications to.
    """
    
    def __init__(self, recipient):
        """
        Initialize an EmailHandler with a recipient.
        
        Args:
            recipient (str): The email address to send notifications to.
        """
        self.recipient = recipient
        
    def run(self, event):
        """
        Send an email notification for the given event.
        
        Args:
            event (Event): The event that triggered this handler.
            
        Returns:
            bool: True if the email was sent successfully, False otherwise.
        """
        # TODO: Implement actual email sending logic
        try:
            # Example implementation:
            # from mojo.helpers.mail import send_mail
            # subject = f"Incident Alert: {event.name}"
            # body = f"An incident has been detected:\n\n{event.details}\n\nMetadata: {event.metadata}"
            # result = send_mail(subject, body, [self.recipient])
            # return result
            return True
        except Exception as e:
            # Log the error
            # logger.error(f"Error sending email to {self.recipient}: {e}")
            return False


class NotifyHandler:
    """
    Handler for sending notifications through various channels based on events.
    
    This handler can send notifications through multiple channels (SMS, push, etc.)
    when an event matches rule criteria.
    
    Attributes:
        recipient (str): The recipient identifier (can be a username, user ID, etc.).
    """
    
    def __init__(self, recipient):
        """
        Initialize a NotifyHandler with a recipient.
        
        Args:
            recipient (str): The recipient identifier.
        """
        self.recipient = recipient
        
    def run(self, event):
        """
        Send a notification for the given event.
        
        Args:
            event (Event): The event that triggered this handler.
            
        Returns:
            bool: True if the notification was sent successfully, False otherwise.
        """
        # TODO: Implement actual notification logic
        try:
            # Example implementation:
            # from mojo.helpers.notifications import send_notification
            # message = f"Incident Alert: {event.name}\n{event.details}"
            # result = send_notification(self.recipient, message, metadata=event.metadata)
            # return result
            return True
        except Exception as e:
            # Log the error
            # logger.error(f"Error sending notification to {self.recipient}: {e}")
            return False

==> django_nativemojo-0.1.104.tar.gz: django_nativemojo-0.1.104/mojo/apps/incident/handlers/event_handlers.py <==
"""
Event handlers for incident processing.

This module contains handlers for processing incident events based on different
handler types (task, email, notify, ticket). These handlers are used by the RuleSet.run_handler
method to handle events that match rule criteria.
Supported handler schemes:
- task://name?param1=value1
- email://recipient@example.com
- notify://user-or-channel
- ticket://?status=open&priority=8
"""

class TaskHandler:
    """
    Handler for executing tasks based on events.

    This handler executes a named task with the given parameters
    when an event matches rule criteria.

    Attributes:
        handler_name (str): The name of the task to execute.
        params (dict): Parameters to pass to the task.
    """

    def __init__(self, handler_name, **params):
        """
        Initialize a TaskHandler with a task name and parameters.

        Args:
            handler_name (str): The name of the task to execute.
            **params: Parameters to pass to the task.
        """
        self.handler_name = handler_name
        self.params = params

    def run(self, event):
        """
        Execute the task for the given event.

        Args:
            event (Event): The event that triggered this handler.

        Returns:
            bool: True if the task was executed successfully, False otherwise.
        """
        # TODO: Implement actual task execution logic
        # For example, using Celery to execute tasks asynchronously
        try:
            # Example implementation:
            # from mojo.tasks import execute_task
            # result = execute_task.delay(self.handler_name, event=event, **self.params)
            # return result.successful()
            return True
        except Exception as e:
            # Log the error
            # logger.error(f"Error executing task {self.handler_name}: {e}")
            return False


class EmailHandler:
    """
    Handler for sending email notifications based on events.

    This handler sends an email to the specified recipient
    when an event matches rule criteria.

    Attributes:
        recipient (str): The email address to send notifications to.
    """

    def __init__(self, recipient):
        """
        Initialize an EmailHandler with a recipient.

        Args:
            recipient (str): The email address to send notifications to.
        """
        self.recipient = recipient

    def run(self, event):
        """
        Send an email notification for the given event.

        Args:
            event (Event): The event that triggered this handler.

        Returns:
            bool: True if the email was sent successfully, False otherwise.
        """
        # TODO: Implement actual email sending logic
        try:
            # Example implementation:
            # from mojo.helpers.mail import send_mail
            # subject = f"Incident Alert: {event.name}"
            # body = f"An incident has been detected:\n\n{event.details}\n\nMetadata: {event.metadata}"
            # result = send_mail(subject, body, [self.recipient])
            # return result
            return True
        except Exception as e:
            # Log the error
            # logger.error(f"Error sending email to {self.recipient}: {e}")
            return False


class NotifyHandler:
    """
    Handler for sending notifications through various channels based on events.

    This handler can send notifications through multiple channels (SMS, push, etc.)
    when an event matches rule criteria.

    Attributes:
        recipient (str): The recipient identifier (can be a username, user ID, etc.).
    """

    def __init__(self, recipient):
        """
        Initialize a NotifyHandler with a recipient.

        Args:
            recipient (str): The recipient identifier.
        """
        self.recipient = recipient

    def run(self, event):
        """
        Send a notification for the given event.

        Args:
            event (Event): The event that triggered this handler.

        Returns:
            bool: True if the notification was sent successfully, False otherwise.
        """
        # TODO: Implement actual notification logic
        try:
            # Example implementation:
            # from mojo.helpers.notifications import send_notification
            # message = f"Incident Alert: {event.name}\n{event.details}"
            # result = send_notification(self.recipient, message, metadata=event.metadata)
            # return result
            return True
        except Exception as e:
            # Log the error
            # logger.error(f"Error sending notification to {self.recipient}: {e}")
            return False


class TicketHandler:
    """
    Handler for creating a ticket based on events.

    This handler creates a ticket linked to the incident (if available) when
    an event matches rule criteria.

    Attributes:
        params (dict): Optional parameters to override ticket fields:
            - title, description, status, priority, category, assignee
    """

    def __init__(self, target=None, **params):
        """
        Initialize a TicketHandler with optional parameters.
        A target is accepted for URL compatibility but ignored.

        Args:
            target (str|None): Unused placeholder for URL netloc.
            **params: Ticket field overrides.
        """
        self.params = params

    def run(self, event):
        """
        Create a ticket for the given event.

        Args:
            event (Event): The event that triggered this handler.

        Returns:
            bool: True if the ticket was created successfully, False otherwise.
        """
        try:
            from mojo.apps.incident.models import Ticket
            title = self.params.get("title") or (getattr(event, "title", None) or "Auto-generated ticket")
            description = self.params.get("description") or (getattr(event, "details", None) or "")
            status = self.params.get("status", "open")
            category = self.params.get("category", "incident")
            try:
                priority = int(self.params.get("priority", getattr(event, "level", 1) or 1))
            except Exception:
                priority = 1

            # Optional: assignee by id
            assignee = None
            assignee_id = self.params.get("assignee")
            if assignee_id:
                try:
                    from django.contrib.auth import get_user_model
                    User = get_user_model()
                    assignee = User.objects.filter(id=int(assignee_id)).first()
                except Exception:
                    assignee = None

            Ticket.objects.create(
                title=title,
                description=description,
                status=status,
                priority=priority,
                category=category,
                assignee=assignee,
                incident=getattr(event, "incident", None),
                metadata={**getattr(event, "metadata", {})},
            )
            return True
        except Exception:
            return False
